org.corfield.rephrase


rephrase-err->msgclj

(rephrase-err->msg e)

Helper to return an error message string from an exception. Copied from clojure.main, updated to call our custom 'to string'.

Helper to return an error message string from an exception.
Copied from `clojure.main`, updated to call our custom 'to string'.
sourceraw docstring

repl-caughtclj

(repl-caught e)

A replacement for clojure.main/repl-caught that rephrases exceptions before printing them. Can be used via the :caught option when starting a REPL.

A replacement for `clojure.main/repl-caught` that rephrases exceptions
before printing them. Can be used via the `:caught` option when starting
a REPL.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries