org.corfield.rephrase.nrepl


middlewareclj

A vector of rephrase middleware, which may be potentially more convenient for other tooling to use (since it 'hides' the descriptor).

A vector of rephrase middleware, which may be potentially more
convenient for other tooling to use (since it 'hides' the descriptor).
sourceraw docstring

wrap-rephraseclj

(wrap-rephrase h)

nREPL middleware that rephrases exceptions to be more beginner-friendly.

nREPL middleware that rephrases exceptions to be more beginner-friendly.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries