(wrap-rephrase h)nREPL middleware that rephrases exceptions to be more beginner-friendly.
nREPL middleware that rephrases exceptions to be more beginner-friendly.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |